@@ -29,8 +29,8 @@ ModuleType = type(sys)
 
 
 __author__ = 'Jure Ziberna'
-__version__ = '0.5.5'
-__date__ = '2012-03-29'
+__version__ = '0.6.0'
+__date__ = '2012-04-18'
 __license__ = 'GNU GPL 3'
 
 
@@ -406,11 +406,11 @@ def __function__(type, message=''):
     message string, calls i3.msg with the resulting arguments and returns a
     response. If message type was command, the function returns success value.
     """
-    message = message.replace('__', ' ')
-    
-    def function(*args):
-        message_full = ' '.join([message] + list(args))
-        response = msg(type, message_full)
+    def function(*args, **criteria):
+        msg_full = ' '.join([message] + list(args))
+        if criteria:
+            msg_full = '%s %s' % (container(**criteria), msg_full)
+        response = msg(type, msg_full)
         error = MessageError.parse(response)
         if error:
             raise error
@@ -418,8 +418,8 @@ def __function__(type, message=''):
             return success(response)  # return the value of the success key
         else:
             return response
-    
     function.__name__ = type
+    function.__doc__ = 'Message sender (type: %s, message: %s)' % (type, message)
     return function
 
 
@@ -462,21 +462,15 @@ def success(response):
     """
     if isinstance(response, dict) and 'success' in response:
         return response['success']
-    return None
+    return response
 
 
-def window(command, cls=None, title=None):
+def container(**criteria):
     """
-    Sends a command to a window of a given title and/or class. Example:
-      i3.window('focus', cls='Firefox')
+    Turns keyword arguments into a formatted contaner criteria.
     """
-    cmd = '['
-    if cls:
-        cmd += 'class="%s"' % cls
-    if title:
-        cmd += 'title="%s"' % title
-    cmd += '] %s' % command
-    return success(msg('command', cmd))
+    criteria = ['%s="%s"' % (key, val) for key, val in criteria.items()]
+    return '[%s]' % ' '.join(criteria)
 
 
 def filter(tree=None, **conditions):
